# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Export this package's modules as members:
from .CustomResource import *

# Make subpackages available:
from . import (
    v1,
    v1beta1,
)
